"""Searching data models."""

from hezor_common.data_model.searching.data.api_models import (
    DataRetrieveResult,
    ExecuteRequest,
    ExecuteResponse,
    ParameterPropertySchema,
    ParameterSchema,
    SearchResponse,
    ToolSchema,
)
from hezor_common.data_model.searching.data.knowledge_retrieval_models import (
    Chunk,
    ChunkSearchResultList,
    Community,
    CommunitySearchResultList,
    EntitySearchResultList,
    GalleryPicture,
    KnowledgeSearchResult,
    OntologyEntity,
    PictureSearchResultList,
    ScoredChunk,
    ScoredCommunity,
    ScoredEntity,
    ScoredPicture,
)
from hezor_common.data_model.searching.data.vector_search_models import (
    ChunkMetadata,
    CommunityFinding,
    CommunityMetadata,
    EntityMetadata,
    PictureMetadata,
    RelationshipMetadata,
    SearchResultItem,
    SearchResults,
    VectorSearchRequest,
    VectorSearchResponse,
)

__all__ = [
    # API models
    "ParameterPropertySchema",
    "ParameterSchema",
    "ToolSchema",
    "SearchResponse",
    "ExecuteRequest",
    "ExecuteResponse",
    "DataRetrieveResult",
    # Vector search models
    "VectorSearchRequest",
    "VectorSearchResponse",
    "SearchResults",
    "SearchResultItem",
    "EntityMetadata",
    "RelationshipMetadata",
    "ChunkMetadata",
    "PictureMetadata",
    "CommunityMetadata",
    "CommunityFinding",
    # Knowledge retrieval models
    "Chunk",
    "OntologyEntity",
    "Community",
    "GalleryPicture",
    "ScoredChunk",
    "ScoredEntity",
    "ScoredCommunity",
    "ScoredPicture",
    "ChunkSearchResultList",
    "EntitySearchResultList",
    "CommunitySearchResultList",
    "PictureSearchResultList",
    "KnowledgeSearchResult",
]



"""Hezor Common - Common utilities for Hezor projects."""

__version__ = "0.5.5"


def hello() -> str:
    """Return a greeting message."""
    return "Hello from hezor-common!"


__all__ = ["__version__", "hello"]
